@@ -7,7 +7,11 @@ from tornado.httpserver import HTTPServer
 from tornado.ioloop import IOLoop
 from tornado.wsgi import WSGIContainer
 from datetime import datetime
+import logging
 from code import interact
+from tornado.options import define, options
+
+tornado.options.parse_command_line()
 
 def run(app, host='0.0.0.0', port=8888):
     if app._wsgi == True:
@@ -17,12 +21,11 @@ def run(app, host='0.0.0.0', port=8888):
     #http.bind(port, host)
     http.listen(port)
     #http.start()
-    server_name = 'wsgi server' if app._wsgi else 'app server'
     instance = IOLoop.instance()
-    print '[%s] * %s is running on http://%s:%s' % (datetime.now().strftime('%Y-%m-%d %H:%M:%S'), server_name, host, port)
+    logging.info('- [%s is running on http://%s:%s]' % (app.__class__.__name__, host, port))
     if app.settings['debug'] == True and app._wsgi == False:
         tornado.autoreload.start(instance)
-        print '[%s] * restart with reload' % (datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
+        logging.info('- [%s restart with reload]' % (app.__class__.__name__))
     try:
         instance.start()
     except KeyboardInterrupt:
